==> dynesty-2.0.0.tar.gz: dynesty-2.0.0/README.md <==
[![Build Status](https://github.com/joshspeagle/dynesty/workflows/Dynesty/badge.svg)](https://github.com/joshspeagle/dynesty/actions)
[![Documentation Status](https://readthedocs.org/projects/dynesty/badge/?version=latest)](https://dynesty.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/joshspeagle/dynesty/badge.svg?branch=master)](https://coveralls.io/github/joshspeagle/dynesty?branch=master)[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.6609296.svg)](https://doi.org/10.5281/zenodo.6609296)


dynesty
=======

![dynesty in action](https://github.com/joshspeagle/dynesty/blob/master/docs/images/title.gif)

A Dynamic Nested Sampling package for computing Bayesian posteriors and
evidences. Pure Python. MIT license.

### Documentation
Documentation can be found [here](https://dynesty.readthedocs.io).

### Installation
The most stable release of `dynesty` can be installed
through [pip](https://pip.pypa.io/en/stable) via
```
pip install dynesty
```
The current (less stable) development version can be installed by running
```
python setup.py install
```
from inside the repository.

### Demos
Several Jupyter notebooks that demonstrate most of the available features
of the code can be found 
[here](https://github.com/joshspeagle/dynesty/tree/master/demos).

### Attribution

If you find the package useful in your research, please cite at least *both* of these references:
* The python implementation [DOI](https://doi.org/10.5281/zenodo.3348367)
* The original [paper](https://ui.adsabs.harvard.edu/abs/2020MNRAS.493.3132S/abstract)

and ideally also papers describing the underlying methods (see the [documentation](https://dynesty.readthedocs.io/en/latest/references.html) for more details)

### Reporting issues

If you want to report issues, or have questions, please do that on [github](https://github.com/joshspeagle/dynesty/issues).

==> dynesty-2.0.1.tar.gz: dynesty-2.0.1/README.md <==
[![Build Status](https://github.com/joshspeagle/dynesty/workflows/Dynesty/badge.svg)](https://github.com/joshspeagle/dynesty/actions)
[![Documentation Status](https://readthedocs.org/projects/dynesty/badge/?version=latest)](https://dynesty.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/joshspeagle/dynesty/badge.svg?branch=master)](https://coveralls.io/github/joshspeagle/dynesty?branch=master)[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.6609296.svg)](https://doi.org/10.5281/zenodo.3348367)


dynesty
=======

![dynesty in action](https://github.com/joshspeagle/dynesty/blob/master/docs/images/title.gif)

A Dynamic Nested Sampling package for computing Bayesian posteriors and
evidences. Pure Python. MIT license.

### Documentation
Documentation can be found [here](https://dynesty.readthedocs.io).

### Installation
The most stable release of `dynesty` can be installed
through [pip](https://pip.pypa.io/en/stable) via
```
pip install dynesty
```
The current (less stable) development version can be installed by running
```
python setup.py install
```
from inside the repository.

### Demos
Several Jupyter notebooks that demonstrate most of the available features
of the code can be found 
[here](https://github.com/joshspeagle/dynesty/tree/master/demos).

### Attribution

If you find the package useful in your research, please cite at least *both* of these references:
* The original paper [Speagle (2020)](https://ui.adsabs.harvard.edu/abs/2020MNRAS.493.3132S/abstract)
* The python implementation [Koposov et al. (2022)](https://doi.org/10.5281/zenodo.3348367) (the citation info is at the bottom of the page on the right)


and ideally also papers describing the underlying methods (see the [documentation](https://dynesty.readthedocs.io/en/latest/references.html) for more details)

### Reporting issues

If you want to report issues, or have questions, please do that on [github](https://github.com/joshspeagle/dynesty/issues).

### Contributing

Patches/contributions are welcome! Please see [CONTRIBUTING.md](CONTRIBUTING.md) for more details.
